
// (c) COPYRIGHT 1996-2000 URI
// 
// See the file COPYRIGHT.

// This is the main CGI program which extracts DDS class descriptors from a
// matlab data file. In addition, the descriptors from an external file (if 
// exist, with the same name as the matlab file and extension of .dds)  
// are extracted and added to the in-memory DDS table before it is sent 
// over the network to the client side. 
//
// ReZa 9/27/96

static char rcsid[]={"$Id: mat_dds.cc,v 1.12 2003/02/10 22:42:05 jimg Exp $"};

#include <iostream.h>
#include <string>

#include "config_mat.h"
#include "Error.h"
#include "DDS.h"
#include "cgi_util.h"
#include "DODSFilter.h"

extern bool read_descriptors(DDS &dds, string filename, string *err);

int 
main(int argc, char * argv[])
{
    DDS dds;
    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.send_version_info();
	return 0;
    }

    try {
      // Read the dataset descriptor in memory
      string errMsg;
      if(!read_descriptors(dds, df.get_dataset_name(), &errMsg)){
	ErrMsgT("mat_dds: could not read the DDS information");
	//client error message
	Error e(unknown_error, errMsg);
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
      }

      df.read_ancillary_dds(dds);

      df.send_dds(dds, true);
    }
    catch (Error &e) {
      set_mime_text(cout, dods_error, df.get_cgi_version());
      e.print(cout);
      return 1;
    }

    return 0;
}

// $Log: mat_dds.cc,v $
// Revision 1.12  2003/02/10 22:42:05  jimg
// Merged with 3.2.6.
//
// Revision 1.11.4.1  2001/10/09 22:35:49  jimg
// Removed
//
// Revision 1.11  2000/10/10 00:03:08  jimg
// Moved CVS Logs to the end of each file.
// Added code to handle exceptions thrown by the dap library.
// Added exceptions to the read methods.
// Changed the definition of the read methods to match the dap library.
//
// Revision 1.10  1999/05/04 03:30:52  jimg
// Merged no gnu changes
//
// Revision 1.9.8.1  1999/04/09 05:29:01  brent
// convert String.h code to new standard lib <string>
//
// Revision 1.9  1998/03/20 00:32:21  jimg
// Changed calls to the set_mime_*() to match the new parameters
//
// Revision 1.8  1997/12/30 23:56:24  jimg
// Fixed errant comments.
//
// Revision 1.7  1997/12/30 22:47:59  jimg
// Changed from old style filter to an implementation that uses the DODSFilter
// class.
//
// Revision 1.6  1997/10/04 00:33:21  jimg
// Release 2.14c fixes
//
// Revision 1.5.6.1  1997/09/03 22:21:44  jimg
// Changed to work with the modified MatLabUtil.cc file; global objects are
// now pointers.
//
// Revision 1.5  1997/06/06 03:57:44  jimg
// Changed prototype and call to read_descriptors().
//
// Revision 1.4  1997/05/01 18:36:06  jimg
// Added configureation header.
// Merged changes from interim 2.1.2 version onto main trunk.
//
// Revision 1.3  1996/11/13 05:13:08  reza
// Added complex matrix capability.
//
// Revision 1.2  1996/11/02 18:43:22  jimg
// Fixed syntax error; xonst for const.
// Moved include of cgi_util.h before MAT*.h includes to avoid a redefinition
// of some inscrutable parameter used by the GNU Map classes. One more reason
// to get rid of those nested includes...
//
// Revision 1.1  1996/10/31 14:43:42  reza
// First release of DODS-matlab servers.
